class User < ApplicationRecord
  before_save :encrypt_password
  attr_accessor :password


  has_many :tasks
  has_many :quizes, through: :tasks#, :solutions
  has_many :reviews

  enum usertype: [:lecturer, :student]

  validates :email, { presence: true, uniqueness: true }
  validates :name, presence: true
  validates :password, confirmation: true, if: :password_required?
  validates :neptun, { format: { with: /[a-zA-Z0-9]{6}/ }, uniqueness: true }

  def User.encrypt(pass, salt)
    Digest::SHA1.hexdigest(salt + pass)
  end

  def encrypt_password
    return if password.blank?
    if new_record?
      self.salt = SecureRandom.base64 8
    end
    self.encrypted_password = User.encrypt(password, salt)
  end

  def User.authenticate(email, pass)
    user = User.where(email: email).first
    user && user.authenticated?(pass) ? user : nil
  end

  def authenticated?(pass)
    self.encrypted_password == User.encrypt(pass, self.salt)
  end

  def password_required?
    new_record? || !password.blank?
  end
end
